Index: include/core/SkCanvas.h |
diff --git a/include/core/SkCanvas.h b/include/core/SkCanvas.h |
index 7bf84c978fed4aa0d549c4c29ab94b3f19084aa6..6251917301ae4725909d0985b559995cba642153 100644 |
--- a/include/core/SkCanvas.h |
+++ b/include/core/SkCanvas.h |
@@ -964,20 +964,20 @@ public: |
}; |
// An array of x-coordinates that divide the bitmap vertically. |
- // These must be unique, increasing, and in the set [0, width). |
+ // These must be unique, increasing, and in the set [fBounds.fLeft, fBounds.fRight). |
// Does not have ownership. |
const int* fXDivs; |
// An array of y-coordinates that divide the bitmap horizontally. |
- // These must be unique, increasing, and in the set [0, height). |
+ // These must be unique, increasing, and in the set [fBounds.fTop, fBounds.fBottom). |
// Does not have ownership. |
const int* fYDivs; |
// If non-null, the length of this array must be equal to |
// (fXCount + 1) * (fYCount + 1). Note that we allow the first rect |
// in each direction to empty (divs[0] = 0). In this case, the |
// caller still must specify a flag (as a placeholder) for these |
// empty rects. |
// The flags correspond to the rects in the lattice, first moving |
// left to right and then top to bottom. |
const Flags* fFlags; |
@@ -987,6 +987,10 @@ public: |
// The number of fYDivs. |
int fYCount; |
+ |
+ // The bound to draw from. Will ofetn be equal to the bounds of the |
+ // input SkImage. |
reed1
2016/09/29 21:11:38
1. could take a ptr to a rect, and null means the
|
+ SkIRect fBounds; |
}; |
/** |
@@ -964,20 +964,20 @@ public: |
// If non-null, the length of this array must be equal to |
// (fXCount + 1) * (fYCount + 1). Note that we allow the first rect |
- // in each direction to empty (divs[0] = 0). In this case, the |
- // caller still must specify a flag (as a placeholder) for these |
- // empty rects. |
+ // in each direction to be empty (ex: fXDivs[0] = fBounds.fLeft). |
+ // In this case, the caller still must specify a flag (as a placeholder) |
+ // for these empty rects. |
// The flags correspond to the rects in the lattice, first moving |
// left to right and then top to bottom. |